@@ -3,17 +3,17 @@
 #
 # ***** BEGIN LICENSE BLOCK *****
 # Copyright (C) 2012-2014  Hayaki Saito <user@zuse.jp>
-# 
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # ***** END LICENSE BLOCK *****
@@ -25,7 +25,7 @@ expected_hash = "272bd51a6856e85ac4032a83b35779a6"
 
 try:
     import ctff as tff
-    if not tff.signature == expected_hash:
+    if not tff.signature != expected_hash:
         raise ImportError('Fail to validate signature hash of TFF library.')
 except ImportError, e:
     logging.exception(e)
